.. configuration.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._configuration package.



AutoArchive._configuration
==========================

.. automodule:: AutoArchive._configuration
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   configuration.core



Modules
-------

configuration_base
^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration.configuration_base
   :no-members:

.. autoclass:: ConfigurationBase
   :special-members:
   :exclude-members: __init__, __abstractmethods__, __module__



iapp_config
^^^^^^^^^^^

.. automodule:: AutoArchive._configuration.iapp_config



iconfiguration
^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration.iconfiguration
   :no-members:

.. autoclass:: IConfiguration
   :no-members:
   :members: __getitem__, getRawValue



istorage
^^^^^^^^

.. automodule:: AutoArchive._configuration.istorage



istorage_portion
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration.istorage_portion



options
^^^^^^^

.. automodule:: AutoArchive._configuration.options
